@@ -42,7 +42,7 @@ arma::field<arma::vec> getHybridGvE(const Rcpp::S4& trait,
     output.set_size(1);
     output(0).set_size(nInd);
   }
-  arma::vec x(ploidy+1); // Genotype dossage
+  arma::vec x(ploidy+1); // Genotype dosage
   for(arma::uword i=0; i<x.n_elem; ++i)
     x(i) = double(i);
   arma::vec xa = (x-dP/2.0)*(2.0/dP);
@@ -141,7 +141,7 @@ arma::field<arma::vec> getHybridGv(const Rcpp::S4& trait,
     output.set_size(1);
     output(0).set_size(nInd);
   }
-  arma::vec x(ploidy+1); // Genotype dossage
+  arma::vec x(ploidy+1); // Genotype dosage
   for(arma::uword i=0; i<x.n_elem; ++i)
     x(i) = double(i);
   arma::vec xa = (x-dP/2.0)*(2.0/dP);
